# Visualization

Mask visualization utilities. Requires the `[viz]` extra.

```bash
pip install "panosam[viz] @ git+https://github.com/yz3440/panosam.git"
```

## Functions

::: panosam.sam.utils.extract_mask_contours
    options:
      show_root_heading: true

::: panosam.sam.utils.visualize_masks
    options:
      show_root_heading: true

::: panosam.sam.utils.visualize_sphere_masks
    options:
      show_root_heading: true
